/** @jsx jsx */
import { Fragment, useContext } from 'react';
import { css, jsx } from '@emotion/react';
import { SurfaceContext } from './surface-provider';
const baseStyles = css({
  position: 'absolute',
  inset: 0,
  borderRadius: 'inherit',
  cursor: 'pointer',
  // eslint-disable-next-line @repo/internal/styles/no-nested-styles
  '~ *': {
    position: 'relative',
    pointerEvents: 'none'
  }
});
/**
 *
 * @example
 * ```js
 * // a minimal icon button
 * <Box as="button">
 *   <InteractionSurface>
 *    <WarningIcon label="icon button" />
 *  </InteractionSurface>
 * </Box>
 * ```
 */
const InteractionSurface = ({
  appearance,
  children,
  testId
}) => {
  const defaultSurface = useContext(SurfaceContext);
  let surface = appearance || defaultSurface;

  // This case will occur if the Box has not set a bg color and the ancestor surface
  // is an elevation. An alternative would be to throw an error here as it may be better
  // to ensure correct predictable behaviour based on user specification.
  if (!(surface in backgroundActiveColorMap)) {
    surface = 'neutral';
  }
  return jsx(Fragment, null, jsx("span", {
    "data-testid": testId,
    css: [baseStyles, surface && backgroundHoverColorMap[surface], surface && backgroundActiveColorMap[surface]]
  }), children);
};
export default InteractionSurface;

/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::7edbce89d412711e064a5fa2788f3fa6>>
 * @codegenId interactions
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["background"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-light.tsx <<SignedSource::7e5a6402120dcaf0373e364561a78a73>>
 */
const backgroundActiveColorMap = {
  input: css({
    ':active': {
      backgroundColor: "var(--ds-background-input-pressed, #FFFFFF)"
    }
  }),
  'inverse.subtle': css({
    ':active': {
      backgroundColor: "var(--ds-background-inverse-subtle-pressed, #00000052)"
    }
  }),
  neutral: css({
    ':active': {
      backgroundColor: "var(--ds-background-neutral-pressed, #091E424F)"
    }
  }),
  'neutral.subtle': css({
    ':active': {
      backgroundColor: "var(--ds-background-neutral-subtle-pressed, #091E4224)"
    }
  }),
  'neutral.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-neutral-bold-pressed, #172B4D)"
    }
  }),
  selected: css({
    ':active': {
      backgroundColor: "var(--ds-background-selected-pressed, #85B8FF)"
    }
  }),
  'selected.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-selected-bold-pressed, #09326C)"
    }
  }),
  'brand.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-brand-bold-pressed, #09326C)"
    }
  }),
  danger: css({
    ':active': {
      backgroundColor: "var(--ds-background-danger-pressed, #FF9C8F)"
    }
  }),
  'danger.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-danger-bold-pressed, #601E16)"
    }
  }),
  warning: css({
    ':active': {
      backgroundColor: "var(--ds-background-warning-pressed, #F5CD47)"
    }
  }),
  'warning.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-warning-bold-pressed, #B38600)"
    }
  }),
  success: css({
    ':active': {
      backgroundColor: "var(--ds-background-success-pressed, #7EE2B8)"
    }
  }),
  'success.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-success-bold-pressed, #164B35)"
    }
  }),
  discovery: css({
    ':active': {
      backgroundColor: "var(--ds-background-discovery-pressed, #B8ACF6)"
    }
  }),
  'discovery.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-discovery-bold-pressed, #352C63)"
    }
  }),
  information: css({
    ':active': {
      backgroundColor: "var(--ds-background-information-pressed, #85B8FF)"
    }
  }),
  'information.bold': css({
    ':active': {
      backgroundColor: "var(--ds-background-information-bold-pressed, #09326C)"
    }
  }),
  'elevation.surface': css({
    ':active': {
      backgroundColor: "var(--ds-surface-pressed, #DCDFE4)"
    }
  }),
  'elevation.surface.overlay': css({
    ':active': {
      backgroundColor: "var(--ds-surface-overlay-pressed, #DCDFE4)"
    }
  }),
  'elevation.surface.raised': css({
    ':active': {
      backgroundColor: "var(--ds-surface-raised-pressed, #DCDFE4)"
    }
  })
};
const backgroundHoverColorMap = {
  input: css({
    ':hover': {
      backgroundColor: "var(--ds-background-input-hovered, #F7F8F9)"
    }
  }),
  'inverse.subtle': css({
    ':hover': {
      backgroundColor: "var(--ds-background-inverse-subtle-hovered, #0000003D)"
    }
  }),
  neutral: css({
    ':hover': {
      backgroundColor: "var(--ds-background-neutral-hovered, #091E4224)"
    }
  }),
  'neutral.subtle': css({
    ':hover': {
      backgroundColor: "var(--ds-background-neutral-subtle-hovered, #091E420F)"
    }
  }),
  'neutral.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-neutral-bold-hovered, #2C3E5D)"
    }
  }),
  selected: css({
    ':hover': {
      backgroundColor: "var(--ds-background-selected-hovered, #CCE0FF)"
    }
  }),
  'selected.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-selected-bold-hovered, #0055CC)"
    }
  }),
  'brand.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-brand-bold-hovered, #0055CC)"
    }
  }),
  danger: css({
    ':hover': {
      backgroundColor: "var(--ds-background-danger-hovered, #FFD2CC)"
    }
  }),
  'danger.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-danger-bold-hovered, #AE2A19)"
    }
  }),
  warning: css({
    ':hover': {
      backgroundColor: "var(--ds-background-warning-hovered, #F8E6A0)"
    }
  }),
  'warning.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-warning-bold-hovered, #CF9F02)"
    }
  }),
  success: css({
    ':hover': {
      backgroundColor: "var(--ds-background-success-hovered, #BAF3DB)"
    }
  }),
  'success.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-success-bold-hovered, #216E4E)"
    }
  }),
  discovery: css({
    ':hover': {
      backgroundColor: "var(--ds-background-discovery-hovered, #DFD8FD)"
    }
  }),
  'discovery.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-discovery-bold-hovered, #5E4DB2)"
    }
  }),
  information: css({
    ':hover': {
      backgroundColor: "var(--ds-background-information-hovered, #CCE0FF)"
    }
  }),
  'information.bold': css({
    ':hover': {
      backgroundColor: "var(--ds-background-information-bold-hovered, #0055CC)"
    }
  }),
  'elevation.surface': css({
    ':hover': {
      backgroundColor: "var(--ds-surface-hovered, #F1F2F4)"
    }
  }),
  'elevation.surface.overlay': css({
    ':hover': {
      backgroundColor: "var(--ds-surface-overlay-hovered, #F1F2F4)"
    }
  }),
  'elevation.surface.raised': css({
    ':hover': {
      backgroundColor: "var(--ds-surface-raised-hovered, #F1F2F4)"
    }
  })
};

/**
 * @codegenEnd
 */