/** @jsx jsx */
import { ReactNode } from 'react';
import type { BasePrimitiveProps } from './types';
/**
 * @private
 * @deprecated DSP-8009: This type is scheduled for deletion.
 * Please use `Inline` from `@atlaskit/primitives` instead.
 */
export interface InlineProps extends BasePrimitiveProps {
    /**
     * Used to align children along the cross axis.
     */
    alignItems?: FlexAlignItems;
    /**
     * Used to align children along the main axis.
     */
    justifyContent?: FlexJustifyContent;
    /**
     * Sets whether children are forced onto one line or can wrap onto multiple lines
     */
    flexWrap?: FlexWrap;
    /**
     * Token representing gap between children.
     */
    gap: ColumnGap;
    /**
     * Renders a divider between children.
     * If a string is provided it will automatically be wrapped in a `<Text>` component.
     */
    divider?: ReactNode;
    /**
     * Elements to be rendered inside the Inline.
     */
    children: ReactNode;
}
type FlexAlignItems = keyof typeof flexAlignItemsMap;
declare const flexAlignItemsMap: {
    center: import("@emotion/react").SerializedStyles;
    baseline: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
};
type FlexJustifyContent = keyof typeof flexJustifyContentMap;
declare const flexJustifyContentMap: {
    center: import("@emotion/react").SerializedStyles;
    flexStart: import("@emotion/react").SerializedStyles;
    'space-between': import("@emotion/react").SerializedStyles;
    flexEnd: import("@emotion/react").SerializedStyles;
    start: import("@emotion/react").SerializedStyles;
    end: import("@emotion/react").SerializedStyles;
    spaceBetween: import("@emotion/react").SerializedStyles;
};
type FlexWrap = keyof typeof flexWrapMap;
declare const flexWrapMap: {
    wrap: import("@emotion/react").SerializedStyles;
};
/**
 * __Inline__
 *
 * Inline is a primitive component based on flexbox that manages the horizontal layout of direct children.
 * Renders a `div` by default.
 *
 * @private
 * @deprecated DSP-8009: This primitive is scheduled for deletion.
 * Please use `Inline` from `@atlaskit/primitives` instead.
 *
 * @example
 * ```tsx
 * const App = () => (
 *   <Inline gap="space.100">
 *     <Button />
 *     <Button />
 *   </Inline>
 * )
 * ```
 */
declare const Inline: import("react").MemoExoticComponent<import("react").ForwardRefExoticComponent<InlineProps & import("react").RefAttributes<HTMLDivElement>>>;
export default Inline;
/**
 * THIS SECTION WAS CREATED VIA CODEGEN DO NOT MODIFY {@see http://go/af-codegen}
 * @codegen <<SignedSource::c96c5857a4f0baed6460df50c2a63f98>>
 * @codegenId spacing
 * @codegenCommand yarn codegen-styles
 * @codegenParams ["columnGap"]
 * @codegenDependency ../../../tokens/src/artifacts/tokens-raw/atlassian-spacing.tsx <<SignedSource::86e173b0e020fe5d091fdf4bff023711>>
 */
declare const columnGapMap: {
    'space.0': import("@emotion/react").SerializedStyles;
    'space.025': import("@emotion/react").SerializedStyles;
    'space.050': import("@emotion/react").SerializedStyles;
    'space.075': import("@emotion/react").SerializedStyles;
    'space.100': import("@emotion/react").SerializedStyles;
    'space.1000': import("@emotion/react").SerializedStyles;
    'space.150': import("@emotion/react").SerializedStyles;
    'space.200': import("@emotion/react").SerializedStyles;
    'space.250': import("@emotion/react").SerializedStyles;
    'space.300': import("@emotion/react").SerializedStyles;
    'space.400': import("@emotion/react").SerializedStyles;
    'space.500': import("@emotion/react").SerializedStyles;
    'space.600': import("@emotion/react").SerializedStyles;
    'space.800': import("@emotion/react").SerializedStyles;
};
export type ColumnGap = keyof typeof columnGapMap;
/**
 * @codegenEnd
 */
